@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '0.61'; # VERSION
+our $DATE = '2015-11-27'; # DATE
+our $VERSION = '0.62'; # VERSION
 
 use 5.010;
 use strict;
@@ -24,6 +24,7 @@ $SPEC{nat} = {
     summary => 'This function produces a stream of natural numbers',
     args => {
         num => {
+            summary => 'Limit number of numbers to produce',
             schema => 'int*',
             cmdline_aliases => {n=>{}},
         },
@@ -95,6 +96,69 @@ sub square_input {
      }];
 }
 
+$SPEC{square_input_from_file} = {
+    v => 1.1,
+    summary => 'This function squares its stream input',
+    args => {
+        input => {
+            req => 1,
+            pos => 0,
+            stream => 1,
+            schema => 'float*',
+            cmdline_src => 'file',
+        },
+    },
+    result => {
+        stream => 1,
+        schema => 'float*',
+    },
+};
+sub square_input_from_file {
+    goto &square_input;
+}
+
+$SPEC{square_input_from_stdin} = {
+    v => 1.1,
+    summary => 'This function squares its stream input',
+    args => {
+        input => {
+            req => 1,
+            pos => 0,
+            stream => 1,
+            schema => 'float*',
+            cmdline_src => 'stdin',
+        },
+    },
+    result => {
+        stream => 1,
+        schema => 'float*',
+    },
+};
+sub square_input_from_stdin {
+    goto &square_input;
+}
+
+$SPEC{square_input_from_stdin_or_file} = {
+    v => 1.1,
+    summary => 'This function squares its stream input',
+    args => {
+        input => {
+            req => 1,
+            pos => 0,
+            stream => 1,
+            schema => 'float*',
+            cmdline_src => 'stdin_or_file',
+        },
+    },
+    result => {
+        stream => 1,
+        schema => 'float*',
+    },
+};
+sub square_input_from_stdin_or_file {
+    goto &square_input;
+}
+
 $SPEC{wc} = {
     v => 1.1,
     summary => 'Count the number of lines/words/characters of input, like the "wc" command',
@@ -170,7 +234,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.61 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-09-29.
+This document describes version 0.62 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-11-27.
 
 =head1 HOMEPAGE
 
@@ -211,7 +275,7 @@ This package contains functions that demonstrate streaming input/output.
 
 This function produces a stream of hashes.
 
-This function is not exported by default, but exportable.
+This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -237,7 +301,7 @@ Return value:  (hash)
 
 This function produces a stream of natural numbers.
 
-This function is not exported by default, but exportable.
+This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -245,6 +309,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<num> => I<int>
 
+Limit number of numbers to produce.
+
 =back
 
 Returns an enveloped result (an array).
@@ -263,7 +329,85 @@ Return value:  (int)
 
 This function squares its stream input.
 
-This function is not exported by default, but exportable.
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<input>* => I<float>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (float)
+
+
+=head2 square_input_from_file(%args) -> [status, msg, result, meta]
+
+This function squares its stream input.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<input>* => I<float>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (float)
+
+
+=head2 square_input_from_stdin(%args) -> [status, msg, result, meta]
+
+This function squares its stream input.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<input>* => I<float>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (float)
+
+
+=head2 square_input_from_stdin_or_file(%args) -> [status, msg, result, meta]
+
+This function squares its stream input.
+
+This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -289,7 +433,7 @@ Return value:  (float)
 
 Count the number of lines/words/characters of input, like the "wc" command.
 
-This function is not exported by default, but exportable.
+This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -318,7 +462,7 @@ Count the number of keys of each hash.
 This is a simple demonstration of accepting a stream of hashes. In command-line
 application this will translate to JSON stream.
 
-This function is not exported by default, but exportable.
+This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
